@@ -15,18 +15,23 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.h,v 1.21 2004/07/24 10:16:10 chpe Exp $
+ *  $Id: EphyBrowser.h,v 1.25.4.2 2004/09/21 11:13:21 chpe Exp $
  */
 
 #ifndef EPHY_BROWSER_H
 #define EPHY_BROWSER_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-encodings.h"
 #include "ephy-embed.h"
 
 #include <gtkmozembed.h>
 #include <nsCOMPtr.h>
 #include <nsIDOMEventListener.h>
+#include <nsIDOMEventTarget.h>
 #include <nsIWebNavigation.h>
 #include <nsISHistory.h>
 #include <nsIWebBrowser.h>
@@ -36,8 +41,7 @@
 #include <nsIRequest.h>
 
 #ifdef ALLOW_PRIVATE_API
-#include <nsIDocShell.h>
-#include <nsIDOMEventReceiver.h>
+#include "nsIContentViewer.h"
 #endif
 
 class EphyEventListener : public nsIDOMEventListener
@@ -106,11 +110,13 @@ public:
 	nsresult GetSHUrlAtIndex (PRInt32 index, nsACString &url);
 	nsresult GoToHistoryIndex (PRInt16 index);
 
-	enum { RELOAD_NORMAL = 0 };
-	enum { RELOAD_FORCE = 1 };
-	enum { RELOAD_ENCODING_CHANGE = 2 };
+#ifdef GTKMOZEMBED_BROKEN_RELOAD
+	enum ReloadType { RELOAD_NORMAL		 = 0,
+			  RELOAD_FORCE		 = 1,
+			  RELOAD_ENCODING_CHANGE = 2 };
 
-	nsresult Reload (PRUint32 flags);
+	nsresult Reload (ReloadType flags);
+#endif
 
 	nsresult ForceEncoding (const char *encoding);
 	nsresult GetEncoding (nsACString &encoding);
@@ -134,7 +140,7 @@ public:
 
 private:
 	nsCOMPtr<nsIDOMDocument> mTargetDocument;
-	nsCOMPtr<nsIDOMEventReceiver> mEventReceiver;
+	nsCOMPtr<nsIDOMEventTarget> mEventTarget;
 	nsCOMPtr<nsIDOMWindow> mDOMWindow;
 	nsCOMPtr<nsISupports> mSecurityInfo;
 	EphyFaviconEventListener *mFaviconEventListener;
