@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GtkNSSDialogs.cpp,v 1.15 2004/06/17 17:57:12 chpe Exp $
+ *  $Id: GtkNSSDialogs.cpp,v 1.17.4.1 2004/09/26 16:48:26 chpe Exp $
  */
 
 /*
@@ -26,6 +26,8 @@
  * or expired certificate.
  */
 
+#include "mozilla-config.h"
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -1221,6 +1223,7 @@ setup_view_cert_tree (GtkWidget *dialog, GladeXML*gxml, nsIArray *certChain)
 						  G_TYPE_STRING,
 						  G_TYPE_POINTER);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (chain_tree_view), GTK_TREE_MODEL (store));
+	g_object_unref (store);
 
 
 	renderer = gtk_cell_renderer_text_new ();
@@ -1242,6 +1245,7 @@ setup_view_cert_tree (GtkWidget *dialog, GladeXML*gxml, nsIArray *certChain)
 				    G_TYPE_STRING,
 				    G_TYPE_POINTER);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (field_tree_view), GTK_TREE_MODEL (store));
+	g_object_unref (store);
 
 
 	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (field_tree_view),
@@ -1345,11 +1349,11 @@ GtkNSSDialogs::ViewCert(nsIInterfaceRequestor *ctx,
 		text = _("Could not verify this certificate for unknown reasons.");
 	}
 	
-	char *msg = g_strdup_printf ("<b>%s</b>", text);
+	char *vmsg = g_strdup_printf ("<b>%s</b>", text);
 	widget = glade_xml_get_widget (gxml, "label_verify_text");
 	g_return_val_if_fail (GTK_IS_LABEL (widget), NS_ERROR_FAILURE);
-	gtk_label_set_markup (GTK_LABEL (widget), msg);
-	g_free (msg);
+	gtk_label_set_markup (GTK_LABEL (widget), vmsg);
+	g_free (vmsg);
 
 	if (count > 0)
 	{
