@@ -1,6 +1,6 @@
 /*  vim:set ts=8 noet sw=8:
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright (C) 2000-2004 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.87 2004/07/30 19:56:08 chpe Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.92.4.3 2004/10/07 11:15:47 marco Exp $
  */
 
 #include "mozilla-config.h"
@@ -26,7 +26,6 @@
 #endif
 
 #include "mozilla-embed-single.h"
-#include "mozilla-version.h"
 
 #include "ephy-cookie-manager.h"
 #include "ephy-password-manager.h"
@@ -45,6 +44,7 @@
 #include "EphySingle.h"
 #include "EphyBrowser.h"
 #include "EphyUtils.h"
+#include "MozillaPrivate.h"
 
 #include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
@@ -71,9 +71,14 @@
 #include <nsIPassword.h>
 #endif
 
+#if defined (HAVE_CHROME_NSICHROMEREGISTRYSEA_H)
+#include <chrome/nsIChromeRegistrySea.h>
+#elif defined(MOZ_NSIXULCHROMEREGISTRY_SELECTSKIN)
+#include <nsIChromeRegistry.h>
+#endif
+
 #ifdef ALLOW_PRIVATE_API
 // FIXME: For setting the locale. hopefully gtkmozembed will do itself soon
-#include <nsIChromeRegistry.h>
 #include <nsILocaleService.h>
 #include <nsIHttpAuthManager.h>
 #include <nsICacheService.h>
@@ -204,6 +209,22 @@ mozilla_set_default_prefs (MozillaEmbedSingle *mes)
 		return FALSE;
         }
                                                                                                                              
+	nsCOMPtr<nsIPrefBranch> pref;
+	prefService->GetBranch ("", getter_AddRefs(pref));
+	NS_ENSURE_TRUE (pref, FALSE);
+
+	/* We do this before reading the user pref file so that the user
+	 * still can overwrite this pref.
+	 * We don't use the default-prefs.js file since that cannot be
+	 * localised (see bug #144909).
+	 */
+	/* translators: this is the URL that searches from the location
+	 * entry get directed to. The search terms will be _appended_ to it,
+	 * in url-escaped UTF-8; that means that if you're choosing google,
+	 * the 'q=' part needs to come last.
+	 */
+	pref->SetCharPref ("keyword.URL", _("http://www.google.com/search?ie=UTF-8&oe=UTF-8&q="));
+
         /* Load the default user preferences as well.  This also makes the
            prefs to be saved in the user's prefs.js file, instead of messing up
            our global defaults file. */
@@ -213,10 +234,6 @@ mozilla_set_default_prefs (MozillaEmbedSingle *mes)
                 g_warning ("failed to read user preferences, error: %x", rv);
         }
 
-        nsCOMPtr<nsIPrefBranch> pref;
-        prefService->GetBranch ("", getter_AddRefs(pref));
-	NS_ENSURE_TRUE (pref, FALSE);
-
 	/* FIXME We need to do this because mozilla doesnt set product
 	sub for embedding apps */
 	pref->SetCharPref ("general.useragent.vendor", "Epiphany");
@@ -294,15 +311,32 @@ mozilla_setup_colors (MozillaEmbedSingle *mes)
 
 static void 
 mozilla_embed_single_new_window_orphan_cb (GtkMozEmbedSingle *embed,
-                      		          GtkMozEmbed **retval, 
-					  guint chrome_mask,
-                           		  EphyEmbedSingle *shell)
+					   GtkMozEmbed **retval, 
+					   guint chrome_mask,
+					   EphyEmbedSingle *shell)
 {
  	g_assert (chrome_mask & GTK_MOZ_EMBED_FLAG_OPENASCHROME);
 
 	*retval = _mozilla_embed_new_xul_dialog ();
 }
 
+static void
+mozilla_init_plugin_path ()
+{
+	const char *user_path;
+	char *new_path;
+
+	user_path = g_getenv ("MOZ_PLUGIN_PATH");
+	new_path = g_strconcat (user_path ? user_path : "",
+				user_path ? ":" : "",
+				MOZILLA_PREFIX "/lib/mozilla/plugins:"
+				MOZILLA_HOME "/plugins",
+				NULL);
+
+	g_setenv ("MOZ_PLUGIN_PATH", new_path, TRUE);
+	g_free (new_path);
+}
+
 static void
 mozilla_init_single (MozillaEmbedSingle *mes)
 {	
@@ -368,18 +402,18 @@ have_gnome_url_handler (const gchar *protocol)
 static nsresult
 getUILang (nsAString& aUILang)
 {
-	nsresult result;
+	nsresult rv;
 
-	nsCOMPtr<nsILocaleService> localeService = do_GetService (NS_LOCALESERVICE_CONTRACTID, &result);
-	if (NS_FAILED (result) || !localeService)
+	nsCOMPtr<nsILocaleService> localeService = do_GetService (NS_LOCALESERVICE_CONTRACTID);
+	if (!localeService)
 	{
 		g_warning ("Could not get locale service!\n");
 		return NS_ERROR_FAILURE;
 	}
 
-	result = localeService->GetLocaleComponentForUserAgent (aUILang);
+	rv = localeService->GetLocaleComponentForUserAgent (aUILang);
 
-	if (NS_FAILED (result))
+	if (NS_FAILED (rv))
 	{
 		g_warning ("Could not determine locale!\n");
 		return NS_ERROR_FAILURE;
@@ -391,27 +425,36 @@ getUILang (nsAString& aUILang)
 static nsresult
 mozilla_init_chrome (void)
 {
-	nsresult result;
+/* FIXME: can we just omit this on new-toolkit ? */
+#if defined(MOZ_NSIXULCHROMEREGISTRY_SELECTSKIN) || defined(HAVE_CHROME_NSICHROMEREGISTRYSEA_H)
+	nsresult rv;
 	nsEmbedString uiLang;
 
+#ifdef HAVE_CHROME_NSICHROMEREGISTRYSEA_H
+	nsCOMPtr<nsIChromeRegistrySea> chromeRegistry = do_GetService (NS_CHROMEREGISTRY_CONTRACTID);
+#else
 	nsCOMPtr<nsIXULChromeRegistry> chromeRegistry = do_GetService (NS_CHROMEREGISTRY_CONTRACTID);
+#endif
 	NS_ENSURE_TRUE (chromeRegistry, NS_ERROR_FAILURE);
 
 	// Set skin to 'classic' so we get native scrollbars.
-	result = chromeRegistry->SelectSkin (nsEmbedCString("classic/1.0"), PR_FALSE);
-	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
+	rv = chromeRegistry->SelectSkin (nsEmbedCString("classic/1.0"), PR_FALSE);
+	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	// set locale
-	result = chromeRegistry->SetRuntimeProvider(PR_TRUE);
-	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
+	rv = chromeRegistry->SetRuntimeProvider(PR_TRUE);
+	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-	result = getUILang(uiLang);
-	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
+	rv = getUILang(uiLang);
+	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
 	nsEmbedCString cUILang;
 	NS_UTF16ToCString (uiLang, NS_CSTRING_ENCODING_UTF8, cUILang);
 
 	return chromeRegistry->SelectLocale (cUILang, PR_FALSE);
+#else
+	return NS_OK;
+#endif
 }
 
 static void
@@ -435,9 +478,13 @@ static gboolean
 init_services (MozillaEmbedSingle *single)
 {
 	/* Pre initialization */
+	mozilla_init_plugin_path ();
 	mozilla_init_home ();
 	mozilla_init_profile ();
 
+	/* Set mozilla binary path */
+	gtk_moz_embed_set_comp_path (MOZILLA_HOME);
+
 	/* Fire up the beast */
 	gtk_moz_embed_push_startup ();
 
@@ -486,6 +533,8 @@ mozilla_embed_single_init (MozillaEmbedSingle *mes)
 	{
 		GtkWidget *dialog;
 
+		/* FIXME Kill references to MOZILLA_FIVE_HOME
+		   when string freeze is over */
 		dialog = gtk_message_dialog_new
 			(NULL,
                          GTK_DIALOG_MODAL,
@@ -615,7 +664,7 @@ impl_get_font_list (EphyEmbedSingle *shell,
 static GList *
 impl_list_cookies (EphyCookieManager *manager)
 {
-	nsresult result;
+	nsresult rv;
 	GList *cookies = NULL;
 	
 	nsCOMPtr<nsICookieManager> cookieManager = 
@@ -632,8 +681,8 @@ impl_list_cookies (EphyCookieManager *manager)
 	     cookieEnumerator->HasMoreElements(&enumResult))
 	{
 		nsCOMPtr<nsICookie> keks;
-		result = cookieEnumerator->GetNext (getter_AddRefs(keks));
-		if (NS_FAILED (result) || !keks) continue;
+		rv = cookieEnumerator->GetNext (getter_AddRefs(keks));
+		if (NS_FAILED (rv) || !keks) continue;
 
 		EphyCookie *cookie = mozilla_cookie_to_ephy_cookie (keks);
 		if (!cookie) continue;
@@ -886,28 +935,31 @@ impl_permission_manager_list (EphyPermissionManager *manager,
 	return list;
 }
 
-static void
+static GtkWidget * 
 impl_open_window (EphyEmbedSingle *single,
 		  EphyEmbed *parent,
 		  const char *address,
+		  const char *name,
 		  const char *features)
 {
 	nsCOMPtr<nsIDOMWindow> domWindow;
-	nsCOMPtr<nsIDOMWindow> dummy;
 
 	if (parent)
 	{
 		EphyBrowser *browser;
 
 		browser = (EphyBrowser *) _mozilla_embed_get_ephy_browser (MOZILLA_EMBED(parent));
-		g_return_if_fail (browser != NULL);
+		g_return_val_if_fail (browser != NULL, NULL);
 
 		browser->GetDOMWindow (getter_AddRefs (domWindow));
 	}
 
 	nsCOMPtr<nsIWindowWatcher> wWatch(do_GetService ("@mozilla.org/embedcomp/window-watcher;1"));
-	wWatch->OpenWindow (domWindow, address, "", features, nsnull,
-			    getter_AddRefs (dummy));
+	nsCOMPtr<nsIDOMWindow> newWindow;
+	wWatch->OpenWindow (domWindow, address, name, features, nsnull,
+			    getter_AddRefs (newWindow));
+
+	return MozillaFindEmbed (newWindow);
 }
 
 static void
