@@ -188,7 +188,52 @@ ephy_marshal_BOOLEAN__STRING_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:INT,INT (./ephy-marshal.list:4) */
+/* VOID:ENUM,INT,BOOLEAN (./ephy-marshal.list:4) */
+extern void ephy_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
+                                                 GValue       *return_value,
+                                                 guint         n_param_values,
+                                                 const GValue *param_values,
+                                                 gpointer      invocation_hint,
+                                                 gpointer      marshal_data);
+void
+ephy_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
+                                     GValue       *return_value,
+                                     guint         n_param_values,
+                                     const GValue *param_values,
+                                     gpointer      invocation_hint,
+                                     gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__ENUM_INT_BOOLEAN) (gpointer     data1,
+                                                       gint         arg_1,
+                                                       gint         arg_2,
+                                                       gboolean     arg_3,
+                                                       gpointer     data2);
+  register GMarshalFunc_VOID__ENUM_INT_BOOLEAN callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 4);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__ENUM_INT_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_enum (param_values + 1),
+            g_marshal_value_peek_int (param_values + 2),
+            g_marshal_value_peek_boolean (param_values + 3),
+            data2);
+}
+
+/* VOID:INT,INT (./ephy-marshal.list:5) */
 extern void ephy_marshal_VOID__INT_INT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -231,7 +276,7 @@ ephy_marshal_VOID__INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,INT (./ephy-marshal.list:5) */
+/* VOID:POINTER,INT (./ephy-marshal.list:6) */
 extern void ephy_marshal_VOID__POINTER_INT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -274,7 +319,7 @@ ephy_marshal_VOID__POINTER_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,BOOLEAN (./ephy-marshal.list:6) */
+/* VOID:POINTER,BOOLEAN (./ephy-marshal.list:7) */
 extern void ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -317,7 +362,7 @@ ephy_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER (./ephy-marshal.list:7) */
+/* VOID:POINTER,POINTER (./ephy-marshal.list:8) */
 extern void ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -360,7 +405,7 @@ ephy_marshal_VOID__POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT (./ephy-marshal.list:8) */
+/* VOID:STRING,INT (./ephy-marshal.list:9) */
 extern void ephy_marshal_VOID__STRING_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -403,7 +448,7 @@ ephy_marshal_VOID__STRING_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,INT,INT (./ephy-marshal.list:9) */
+/* VOID:STRING,INT,INT (./ephy-marshal.list:10) */
 extern void ephy_marshal_VOID__STRING_INT_INT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -448,7 +493,7 @@ ephy_marshal_VOID__STRING_INT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING (./ephy-marshal.list:10) */
+/* VOID:STRING,STRING (./ephy-marshal.list:11) */
 extern void ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -491,7 +536,7 @@ ephy_marshal_VOID__STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,BOOLEAN (./ephy-marshal.list:11) */
+/* VOID:STRING,BOOLEAN (./ephy-marshal.list:12) */
 extern void ephy_marshal_VOID__STRING_BOOLEAN (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
