@@ -15,10 +15,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
+ *  $Id: ephy-new-bookmark.c,v 1.43.4.1 2004/10/04 22:03:24 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <gtk/gtktable.h>
@@ -27,6 +28,7 @@
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkvbox.h>
 #include <gtk/gtkstock.h>
+#include <gtk/gtkimage.h>
 #include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtkeditable.h>
 #include <glib/gi18n.h>
@@ -53,12 +55,17 @@ static void ephy_new_bookmark_get_property (GObject *object,
 
 #define EPHY_NEW_BOOKMARK_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NEW_BOOKMARK, EphyNewBookmarkPrivate))
 
+enum
+{
+	RESPONSE_NEW_TOPIC
+};
+
 struct EphyNewBookmarkPrivate
 {
 	EphyBookmarks *bookmarks;
 	char *location;
 	char *icon;
-	gulong id;
+	guint id;
 
 	GtkWidget *title_entry;
 	GtkWidget *topics_selector;
@@ -157,8 +164,7 @@ ephy_new_bookmark_add (EphyNewBookmark *new_bookmark)
 			           new_bookmark->priv->location);
 	new_bookmark->priv->id = ephy_node_get_id (node);
 
-	ephy_topics_selector_set_bookmark (selector, node);
-	ephy_topics_selector_apply (selector);
+	ephy_topics_selector_apply (selector, node);
 
 	if (new_bookmark->priv->icon)
 	{
@@ -175,6 +181,10 @@ response_cb (EphyNewBookmark *new_bookmark,
 	     int response_id,
 	     gpointer user_data)
 {
+	EphyTopicsSelector *selector;
+
+	selector = EPHY_TOPICS_SELECTOR (new_bookmark->priv->topics_selector);
+
 	switch (response_id)
 	{
 		case GTK_RESPONSE_HELP:
@@ -182,6 +192,9 @@ response_cb (EphyNewBookmark *new_bookmark,
 		       		       "epiphany",
 		       		       "to-create-new-bookmark");
 			break;
+		case RESPONSE_NEW_TOPIC:
+			ephy_topics_selector_new_topic (selector);
+			break;
 		/* For both OK and Cancel we want to destroy the dialog */
 		case GTK_RESPONSE_OK:
 			ephy_new_bookmark_add (new_bookmark);
@@ -281,6 +294,9 @@ ephy_new_bookmark_construct (EphyNewBookmark *editor)
 	gtk_dialog_add_button (GTK_DIALOG (editor),
 			       GTK_STOCK_HELP,
 			       GTK_RESPONSE_HELP);
+	gtk_dialog_add_button (GTK_DIALOG (editor),
+			       _("_New Topic"),
+			       RESPONSE_NEW_TOPIC);
 	gtk_dialog_add_button (GTK_DIALOG (editor),
 			       GTK_STOCK_CANCEL,
 			       GTK_RESPONSE_CANCEL);
@@ -309,7 +325,8 @@ duplicate_dialog_construct (GtkWindow *parent,
 					      GTK_STOCK_OK,
 					      GTK_RESPONSE_OK,
 					      NULL);
-	
+	ephy_gui_set_default_window_icon (GTK_WINDOW (dialog));
+
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
@@ -491,7 +508,7 @@ ephy_new_bookmark_set_icon (EphyNewBookmark *bookmark,
 	bookmark->priv->icon = icon ? g_strdup (icon) : NULL;
 }
 
-gulong
+guint
 ephy_new_bookmark_get_id (EphyNewBookmark *bookmark)
 {
 	return bookmark->priv->id;
