@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.c,v 1.50 2004/07/11 11:43:18 marco Exp $
+ *  $Id: ephy-topic-action.c,v 1.52.4.2 2004/09/27 18:11:40 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -397,7 +397,7 @@ remove_from_model (GtkWidget *widget)
 	pos = get_item_position (widget, NULL);
 
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
-	model = ephy_bookmarks_get_toolbars_model (bookmarks);
+	model = EGG_TOOLBARS_MODEL (ephy_bookmarks_get_toolbars_model (bookmarks));
 
 	egg_toolbars_model_remove_item (model, 0, pos);
 }
@@ -410,7 +410,7 @@ move_in_model (GtkWidget *widget, int direction)
 	int pos, new_pos;
 
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
-	model = ephy_bookmarks_get_toolbars_model (bookmarks);
+	model = EGG_TOOLBARS_MODEL (ephy_bookmarks_get_toolbars_model (bookmarks));
 
 	pos = get_item_position (widget, NULL);
 	new_pos = MAX (0, pos + direction);
@@ -599,7 +599,7 @@ drag_data_get_cb (GtkWidget *widget, GdkDragContext *context,
 	g_return_if_fail (uri != NULL);
 
 	gtk_selection_data_set (selection_data, selection_data->target, 8,
-				uri, strlen (uri));
+				(unsigned char *) uri, strlen (uri));
 
 	g_free (uri);
 }
@@ -660,6 +660,8 @@ drag_motion_cb (GtkWidget *widget, GdkEventMotion *event, EphyTopicAction *actio
 		gtk_menu_popdown (GTK_MENU (widget));
 		gtk_drag_begin (button, target_list, GDK_ACTION_MOVE |
 				GDK_ACTION_COPY, 1, (GdkEvent*)event);
+
+		gtk_target_list_unref (target_list);
 	}
 
 	return TRUE;
@@ -758,14 +760,17 @@ show_context_menu (EphyTopicAction *action, GtkWidget *proxy,
 			gtk_get_current_event_time ());
 }
 
-static void
+static gboolean
 popup_menu_cb (GtkWidget *widget, EphyTopicAction *action)
 {
 	if (gtk_widget_get_ancestor (widget, EPHY_TYPE_BOOKMARKSBAR))
         {
                 show_context_menu (action, widget,
 				   ephy_gui_menu_position_under_widget);
+		return TRUE;
         }
+
+	return FALSE;
 }
 
 static gboolean
@@ -1049,4 +1054,3 @@ ephy_topic_action_new (const char *name, guint id)
 
 	return action;
 }
-
