@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: pdm-dialog.c,v 1.40 2004/08/21 16:45:25 chpe Exp $
+ *  $Id: pdm-dialog.c,v 1.40.4.1 2004/10/04 22:03:23 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -804,7 +804,7 @@ static void
 pdm_dialog_init (PdmDialog *dialog)
 {
 	PdmActionInfo *cookies, *passwords;
-	GtkWidget *notebook;
+	GtkWidget *notebook, *window;
 
 	dialog->priv = EPHY_PDM_DIALOG_GET_PRIVATE (dialog);
 
@@ -817,6 +817,10 @@ pdm_dialog_init (PdmDialog *dialog)
 			       "pdm_dialog",
 			       NULL);
 
+	window = ephy_dialog_get_control (EPHY_DIALOG (dialog),
+					  properties[PROP_WINDOW].id);
+	ephy_gui_set_default_window_icon (GTK_WINDOW (window));
+
 	/**
 	 * Group all Properties and Remove buttons in the same size group to
 	 * avoid the little jerk you get otherwise when switching pages because
